@@ -3,11 +3,13 @@ import os
 from base import ODSCellTypes
 from pyexcel_ods.odsr import ODSBook
 from pyexcel_ods.odsw import ODSWriter
+from pyexcel_io.reader import Reader
 
 
 class TestODSReader(ODSCellTypes):
     def setUp(self):
-        r = ODSBook()
+        r = Reader("ods")
+        r.reader_class = ODSBook
         r.open(os.path.join("tests", "fixtures", "ods_formats.ods"))
         self.data = r.read_all()
         for key in self.data.keys():
@@ -17,17 +19,17 @@ class TestODSReader(ODSCellTypes):
 
 class TestODSWriter(ODSCellTypes):
     def setUp(self):
-        r = ODSBook()
+        r = Reader("ods")
+        r.reader_class = ODSBook
         r.open(os.path.join("tests", "fixtures", "ods_formats.ods"))
+        r.close()
         self.data1 = r.read_all()
         self.testfile = "odswriter.ods"
-        w = ODSWriter()
-        w.open(self.testfile)
+        w = ODSWriter(self.testfile, "ods")
         w.write(self.data1)
         w.close()
-        r2 = ODSBook()
-        r2.open(self.testfile)
-        self.data = r2.read_all()
+        r.open(self.testfile)
+        self.data = r.read_all()
         for key in self.data.keys():
             self.data[key] = list(self.data[key])
 
